@@ -64,8 +64,9 @@ pub mod simple_theme;
 ///
 pub mod prelude {
     pub use super::build::crop::Croppable;
-    pub use super::build::marker::Markerable;
-    pub use super::build::PlotIteratorAndMarkers;
+    pub use super::build::marker::MarkerableExt;
+    pub use super::build::PlotIteratorAndMarkersExt;
+    pub use super::build::PlotIteratorExt;
     pub use super::formatm;
     pub use super::plots;
     pub use super::simple_fmt;
@@ -100,7 +101,7 @@ macro_rules! formatm {
 macro_rules! plots {
     ( $a:expr,$( $x:expr ),* ) => {
         {
-            use $crate::build::PlotIteratorAndMarkers;
+            use $crate::build::PlotIteratorExt;
             let mut a=$a;
             $(
                 let a=a.chain($x);
